@@ -1,8 +1,7 @@
 # Material models
 # Active models
 from .active_model import ActiveModel
-from .active_strain import ActiveStrain
-from .active_stress import ActiveStress
+from .active_model import ActiveModels
 from .guccione import Guccione
 from .holzapfelogden import HolzapfelOgden
 from .linearelastic import LinearElastic
@@ -44,6 +43,5 @@ __all__ = [
     "LinearElastic",
     "StVenantKirchhoff",
     "ActiveModel",
-    "ActiveStrain",
-    "ActiveStress",
+    "ActiveModels",
 ]
